==> photoupload.6.4.6.592.zip: photoupload.lrplugin/NPPExifTool.lua <==
LuaQ     @..\common\NPPExifTool.lua              
   E   @  \                     	A                  	          require 
   NPPLogger 
   NPPUtilities    resetExiftoolFile 
   exiftoolFile        %   +            @ @ @  A   D   F   @ A D   \@B   H          logOutputFunctionName    require 
   NPPUtilities 
   logOutput    INFO 
   Old value =     valueToString        &   &   &   (   (   (   )   )   )   )   )   )   )   )   )   *   *   +      
   NPPUtilities          
   NPPLogger    _exiftoolFile    _exiftoolFileChecked     /   ^    M   D   F  \@ C  A  @ EA  Z  @       E A \     FA \ B @     C      @        B@ CC   C ܃   B@ CC       D      @          logOutputFunctionName    WIN_ENV 
   exiftool.exe 	   exiftool    require 
   NPPPlugin 
   NPPConfig #   configurationSettingValueOrDefault -   configurationExternalBinaryFilesExifToolPath    -ver    findExternalBinaryFile    stringTrimRight    string    char       *@      $@    M   0   0   0   2   8   8   8   9   :   :   :   <   <   >   @   @   @   A   A   A   B   D   D   D   E   F   G   G   G   G   G   G   G   G   G   G   H   H   I   I   K   M   M   O   O   O   O   O   O   O   O   O   O   O   O   O   O   P   P   P   P   P   P   P   P   P   R   T   T   X   Y   Z   ]   ]   ]   ]   ^         taskID     L      exiftoolFilePathWithName    L   
   errorMessage    L      exiftoolVersion    L   	   fileName    E   
   NPPPlugin    E   
   NPPConfig    E      ok    E      filePathWithName    E      configurationPath    E      fileCommandLineArguments    E      commandLineOutput    E      
   NPPLogger    _exiftoolFileChecked    _exiftoolFile    _exiftoolFileErrorMessage 
   NPPUtilities    _exiftoolVersion                               +   +   +   +   %   ^   ^   ^   ^   ^   ^   ^   /   b   b         NPPExifTool       
   NPPLogger       
   NPPUtilities          _exiftoolFileChecked          _exiftoolFile 	         _exiftoolFileErrorMessage 	         _exiftoolVersion 	          

==> photoupload.6.4.7.667.zip: photoupload.lrplugin/NPPExifTool.lua <==
LuaQ     @..\common\NPPExifTool.lua              
   E   @  \                     	A                  	          require 
   NPPLogger 
   NPPUtilities    resetExiftoolFile 
   exiftoolFile        %   +            @ @ @  A   D   F   @  \@ B   H          logOutputFunctionName    require 
   NPPUtilities 
   logOutput    INFO 
   Old value =         &   &   &   (   (   (   )   )   )   )   )   )   *   *   +      
   NPPUtilities          
   NPPLogger    _exiftoolFile    _exiftoolFileChecked     /   ^    M   D   F  \@ C  A  @ EA  Z  @       E A \     FA \ B @     C      @        B@ CC   C ܃   B@ CC       D      @          logOutputFunctionName    WIN_ENV 
   exiftool.exe 	   exiftool    require 
   NPPPlugin 
   NPPConfig #   configurationSettingValueOrDefault -   configurationExternalBinaryFilesExifToolPath    -ver    findExternalBinaryFile    stringTrimRight    string    char       *@      $@    M   0   0   0   2   8   8   8   9   :   :   :   <   <   >   @   @   @   A   A   A   B   D   D   D   E   F   G   G   G   G   G   G   G   G   G   G   H   H   I   I   K   M   M   O   O   O   O   O   O   O   O   O   O   O   O   O   O   P   P   P   P   P   P   P   P   P   R   T   T   X   Y   Z   ]   ]   ]   ]   ^         taskID     L      exiftoolFilePathWithName    L   
   errorMessage    L      exiftoolVersion    L   	   fileName    E   
   NPPPlugin    E   
   NPPConfig    E      ok    E      filePathWithName    E      configurationPath    E      fileCommandLineArguments    E      commandLineOutput    E      
   NPPLogger    _exiftoolFileChecked    _exiftoolFile    _exiftoolFileErrorMessage 
   NPPUtilities    _exiftoolVersion                               +   +   +   +   %   ^   ^   ^   ^   ^   ^   ^   /   b   b         NPPExifTool       
   NPPLogger       
   NPPUtilities          _exiftoolFileChecked          _exiftoolFile 	         _exiftoolFileErrorMessage 	         _exiftoolVersion 	          
